
# Type: frequency value




URI: [biolink:FrequencyValue](https://w3id.org/biolink/vocab/FrequencyValue)

|  |  |  |
| --- | --- | --- |
| Parent type | | [String](types/String.md) |
| Root (builtin) type | | **str** |
